-- ============================================================
--   Database name:  MODEL_1                                   
--   DBMS name:      ORACLE Version 7.x                        
--   Created on:     26.5.1999  15:23                          
-- ============================================================

-- Integrity package declaration
create or replace package IntegrityPackage AS
 procedure InitNestLevel;
 function GetNestLevel return number;
 procedure NextNestLevel;
 procedure PreviousNestLevel;
 end IntegrityPackage;
/

-- Integrity package definition
create or replace package body IntegrityPackage AS
 NestLevel number;

-- Procedure to initialize the trigger nest level
 procedure InitNestLevel is
 begin
 NestLevel := 0;
 end;


-- Function to return the trigger nest level
 function GetNestLevel return number is
 begin
 if NestLevel is null then
     NestLevel := 0;
 end if;
 return(NestLevel);
 end;

-- Procedure to increase the trigger nest level
 procedure NextNestLevel is
 begin
 if NestLevel is null then
     NestLevel := 0;
 end if;
 NestLevel := NestLevel + 1;
 end;

-- Procedure to decrease the trigger nest level
 procedure PreviousNestLevel is
 begin
 NestLevel := NestLevel - 1;
 end;

 end IntegrityPackage;
/

--  After update trigger "tua_x_dilna" for table "X_DILNA"
create trigger tua_x_dilna after update
of CIS_DIL
on X_DILNA for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
begin
    IntegrityPackage.NextNestLevel;
    
    --  Modify parent code of "X_DILNA" for all children in "X_DILNA_TV"
    if (updating('CIS_DIL') and :old.CIS_DIL != :new.CIS_DIL) then
       update X_DILNA_TV
        set   CIS_DIL = :new.CIS_DIL
       where  CIS_DIL = :old.CIS_DIL;
    end if;
    
    --  Modify parent code of "X_DILNA" for all children in "X_PRAC_MISTO"
    if (updating('CIS_DIL') and :old.CIS_DIL != :new.CIS_DIL) then
       update X_PRAC_MISTO
        set   CIS_DIL = :new.CIS_DIL
       where  CIS_DIL = :old.CIS_DIL;
    end if;
    IntegrityPackage.PreviousNestLevel;

--  gestion des erreurs
exception
    when integrity_error then
       begin
       IntegrityPackage.InitNestLevel;
       raise_application_error(errno, errmsg);
       end;
end;
/

--  Before delete trigger "tdb_x_dilna" for table "X_DILNA"
create trigger tdb_x_dilna before delete
on X_DILNA for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    
    --  Declaration of DeleteParentRestrict constraint for "X_DILNA_TV"
    cursor cfk1_x_dilna(var_cis_dil number) is
       select 1
       from   X_DILNA_TV
       where  CIS_DIL = var_cis_dil
        and   var_cis_dil is not null;
    
    --  Declaration of DeleteParentRestrict constraint for "X_PRAC_MISTO"
    cursor cfk2_x_dilna(var_cis_dil number) is
       select 1
       from   X_PRAC_MISTO
       where  CIS_DIL = var_cis_dil
        and   var_cis_dil is not null;

begin
    
    --  Cannot delete parent "X_DILNA" if children still exist in "X_DILNA_TV"
    open  cfk1_x_dilna(:old.CIS_DIL);
    fetch cfk1_x_dilna into dummy;
    found := cfk1_x_dilna%FOUND;
    close cfk1_x_dilna;
    if found then
       errno  := -20006;
       errmsg := 'Children still exist in "X_DILNA_TV". Cannot delete parent "X_DILNA".';
       raise integrity_error;
    end if;
    
    --  Cannot delete parent "X_DILNA" if children still exist in "X_PRAC_MISTO"
    open  cfk2_x_dilna(:old.CIS_DIL);
    fetch cfk2_x_dilna into dummy;
    found := cfk2_x_dilna%FOUND;
    close cfk2_x_dilna;
    if found then
       errno  := -20006;
       errmsg := 'Children still exist in "X_PRAC_MISTO". Cannot delete parent "X_DILNA".';
       raise integrity_error;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

--  Before insert trigger "tib_x_dilna_tv" for table "X_DILNA_TV"
create trigger tib_x_dilna_tv before insert
on X_DILNA_TV for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_DILNA"
    cursor cpk1_x_dilna_tv(var_cis_dil number) is
       select 1
       from   X_DILNA
       where  CIS_DIL = var_cis_dil
        and   var_cis_dil is not null;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_TYP_VYROBKU"
    cursor cpk2_x_dilna_tv(var_ozn_typu varchar) is
       select 1
       from   X_TYP_VYROBKU
       where  OZN_TYPU = var_ozn_typu
        and   var_ozn_typu is not null;

begin
    
    --  Parent "X_DILNA" must exist when inserting a child in "X_DILNA_TV"
    if :new.CIS_DIL is not null then
       open  cpk1_x_dilna_tv(:new.CIS_DIL);
       fetch cpk1_x_dilna_tv into dummy;
       found := cpk1_x_dilna_tv%FOUND;
       close cpk1_x_dilna_tv;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_DILNA". Cannot create child in "X_DILNA_TV".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_TYP_VYROBKU" must exist when inserting a child in "X_DILNA_TV"
    if :new.OZN_TYPU is not null then
       open  cpk2_x_dilna_tv(:new.OZN_TYPU);
       fetch cpk2_x_dilna_tv into dummy;
       found := cpk2_x_dilna_tv%FOUND;
       close cpk2_x_dilna_tv;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_TYP_VYROBKU". Cannot create child in "X_DILNA_TV".';
          raise integrity_error;
       end if;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

--  Before update trigger "tub_x_dilna_tv" for table "X_DILNA_TV"
create trigger tub_x_dilna_tv before update
of CIS_DIL,
   OZN_TYPU
on X_DILNA_TV for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    seq NUMBER;
    
    --  Declaration of UpdateChildParentExist constraint for the parent "X_DILNA"
    cursor cpk1_x_dilna_tv(var_cis_dil number) is
       select 1
       from   X_DILNA
       where  CIS_DIL = var_cis_dil
        and   var_cis_dil is not null;
    
    --  Declaration of UpdateChildParentExist constraint for the parent "X_TYP_VYROBKU"
    cursor cpk2_x_dilna_tv(var_ozn_typu varchar) is
       select 1
       from   X_TYP_VYROBKU
       where  OZN_TYPU = var_ozn_typu
        and   var_ozn_typu is not null;

begin
    seq := IntegrityPackage.GetNestLevel;
    
    --  Parent "X_DILNA" must exist when updating a child in "X_DILNA_TV"
    if (:new.CIS_DIL is not null) and (seq = 0) then 
       open  cpk1_x_dilna_tv(:new.CIS_DIL);
       fetch cpk1_x_dilna_tv into dummy;
       found := cpk1_x_dilna_tv%FOUND;
       close cpk1_x_dilna_tv;
       if not found then
          errno  := -20003;
          errmsg := 'Parent does not exist in "X_DILNA". Cannot update child in "X_DILNA_TV".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_TYP_VYROBKU" must exist when updating a child in "X_DILNA_TV"
    if (:new.OZN_TYPU is not null) and (seq = 0) then 
       open  cpk2_x_dilna_tv(:new.OZN_TYPU);
       fetch cpk2_x_dilna_tv into dummy;
       found := cpk2_x_dilna_tv%FOUND;
       close cpk2_x_dilna_tv;
       if not found then
          errno  := -20003;
          errmsg := 'Parent does not exist in "X_TYP_VYROBKU". Cannot update child in "X_DILNA_TV".';
          raise integrity_error;
       end if;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

--  Before insert trigger "tib_x_prac_misto" for table "X_PRAC_MISTO"
create trigger tib_x_prac_misto before insert
on X_PRAC_MISTO for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_SKLAD"
    cursor cpk1_x_prac_misto(var_cis_skl number) is
       select 1
       from   X_SKLAD
       where  CIS_SKL = var_cis_skl
        and   var_cis_skl is not null;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_DILNA"
    cursor cpk2_x_prac_misto(var_cis_dil number) is
       select 1
       from   X_DILNA
       where  CIS_DIL = var_cis_dil
        and   var_cis_dil is not null;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_PRACOVNIK"
    cursor cpk3_x_prac_misto(var_rod_cis number) is
       select 1
       from   X_PRACOVNIK
       where  ROD_CIS = var_rod_cis
        and   var_rod_cis is not null;

begin
    
    --  Parent "X_SKLAD" must exist when inserting a child in "X_PRAC_MISTO"
    if :new.CIS_SKL is not null then
       open  cpk1_x_prac_misto(:new.CIS_SKL);
       fetch cpk1_x_prac_misto into dummy;
       found := cpk1_x_prac_misto%FOUND;
       close cpk1_x_prac_misto;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_SKLAD". Cannot create child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_DILNA" must exist when inserting a child in "X_PRAC_MISTO"
    if :new.CIS_DIL is not null then
       open  cpk2_x_prac_misto(:new.CIS_DIL);
       fetch cpk2_x_prac_misto into dummy;
       found := cpk2_x_prac_misto%FOUND;
       close cpk2_x_prac_misto;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_DILNA". Cannot create child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_PRACOVNIK" must exist when inserting a child in "X_PRAC_MISTO"
    if :new.ROD_CIS is not null then
       open  cpk3_x_prac_misto(:new.ROD_CIS);
       fetch cpk3_x_prac_misto into dummy;
       found := cpk3_x_prac_misto%FOUND;
       close cpk3_x_prac_misto;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_PRACOVNIK". Cannot create child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

-- --------------------------------------------------------------------------------- ZACATEK MOJE

-- After insert trigger "ti_x_pm" for table "X_PRAC_MISTO"
create trigger ti_x_pm after insert
of cis_dil,
   cis_skl
on X_PRAC_MISTO for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy1           integer;
    dummy2           integer;
    found            boolean;

    -- Deklarace after insert constraint for X_PRAC_MISTO
    cursor muj_kursor (cd number, cs number) is
	select CIS_DIL, CIS_SKL
		from x_prac_misto
		where (CIS_SKL = cs) and (CIS_DIL = cd) and
			((cd is null and cs is null) or
			(cd is not null and cs is not null));

    -- Vybrane radky musim zrusit
    open muj_kursor;
--   fetch muj_kursor into (:dummy1, :dummy2);
    found := muj_kursor%FOUND;
    close muj_kursor;
	if not found then
	  errno  := -20000;
	  errmsg := 'Musi byt vyplnen jen jeden z atributu CIS_DIL a CIS_SKL. Radek nebyl vlozen.';
	  raise integrity_error;
	end if;
    
--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/
-- ----------------------------------------------------------------------------------- KONEC MOJE

--  Before update trigger "tub_x_prac_misto" for table "X_PRAC_MISTO"
create trigger tub_x_prac_misto before update
of CIS_PM,
   CIS_SKL,
   CIS_DIL,
   ROD_CIS
on X_PRAC_MISTO for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    seq NUMBER;
    
    --  Declaration of UpdateChildParentExist constraint for the parent "X_SKLAD"
    cursor cpk1_x_prac_misto(var_cis_skl number) is
       select 1
       from   X_SKLAD
       where  CIS_SKL = var_cis_skl
        and   var_cis_skl is not null;
    
    --  Declaration of UpdateChildParentExist constraint for the parent "X_DILNA"
    cursor cpk2_x_prac_misto(var_cis_dil number) is
       select 1
       from   X_DILNA
       where  CIS_DIL = var_cis_dil
        and   var_cis_dil is not null;
    
    --  Declaration of UpdateChildParentExist constraint for the parent "X_PRACOVNIK"
    cursor cpk3_x_prac_misto(var_rod_cis number) is
       select 1
       from   X_PRACOVNIK
       where  ROD_CIS = var_rod_cis
        and   var_rod_cis is not null;

begin
    seq := IntegrityPackage.GetNestLevel;
    
    --  Parent "X_SKLAD" must exist when updating a child in "X_PRAC_MISTO"
    if (:new.CIS_SKL is not null) and (seq = 0) then 
       open  cpk1_x_prac_misto(:new.CIS_SKL);
       fetch cpk1_x_prac_misto into dummy;
       found := cpk1_x_prac_misto%FOUND;
       close cpk1_x_prac_misto;
       if not found then
          errno  := -20003;
          errmsg := 'Parent does not exist in "X_SKLAD". Cannot update child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_DILNA" must exist when updating a child in "X_PRAC_MISTO"
    if (:new.CIS_DIL is not null) and (seq = 0) then 
       open  cpk2_x_prac_misto(:new.CIS_DIL);
       fetch cpk2_x_prac_misto into dummy;
       found := cpk2_x_prac_misto%FOUND;
       close cpk2_x_prac_misto;
       if not found then
          errno  := -20003;
          errmsg := 'Parent does not exist in "X_DILNA". Cannot update child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_PRACOVNIK" must exist when updating a child in "X_PRAC_MISTO"
    if (:new.ROD_CIS is not null) and (seq = 0) then 
       open  cpk3_x_prac_misto(:new.ROD_CIS);
       fetch cpk3_x_prac_misto into dummy;
       found := cpk3_x_prac_misto%FOUND;
       close cpk3_x_prac_misto;
       if not found then
          errno  := -20003;
          errmsg := 'Parent does not exist in "X_PRACOVNIK". Cannot update child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

--  After update trigger "tua_x_pracovnik" for table "X_PRACOVNIK"
create trigger tua_x_pracovnik after update
of ROD_CIS
on X_PRACOVNIK for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
begin
    IntegrityPackage.NextNestLevel;
    
    --  Modify parent code of "X_PRACOVNIK" for all children in "X_PRAC_MISTO"
    if (updating('ROD_CIS') and :old.ROD_CIS != :new.ROD_CIS) then
       update X_PRAC_MISTO
        set   ROD_CIS = :new.ROD_CIS
       where  ROD_CIS = :old.ROD_CIS;
    end if;
    IntegrityPackage.PreviousNestLevel;

--  gestion des erreurs
exception
    when integrity_error then
       begin
       IntegrityPackage.InitNestLevel;
       raise_application_error(errno, errmsg);
       end;
end;
/

--  After delete trigger "tda_x_pracovnik" for table "X_PRACOVNIK"
create trigger tda_x_pracovnik after delete
on X_PRACOVNIK for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;

begin
    IntegrityPackage.NextNestLevel;
    
    --  Delete all children in "X_PRAC_MISTO"
    delete X_PRAC_MISTO
    where  ROD_CIS = :old.ROD_CIS;
    IntegrityPackage.PreviousNestLevel;

--  gestion des erreurs
exception
    when integrity_error then
       begin
       IntegrityPackage.InitNestLevel;
       raise_application_error(errno, errmsg);
       end;
end;
/

--  After update trigger "tua_x_sklad" for table "X_SKLAD"
create trigger tua_x_sklad after update
of CIS_SKL
on X_SKLAD for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
begin
    IntegrityPackage.NextNestLevel;
    
    --  Modify parent code of "X_SKLAD" for all children in "X_PRAC_MISTO"
    if (updating('CIS_SKL') and :old.CIS_SKL != :new.CIS_SKL) then
       update X_PRAC_MISTO
        set   CIS_SKL = :new.CIS_SKL
       where  CIS_SKL = :old.CIS_SKL;
    end if;
    
    --  Modify parent code of "X_SKLAD" for all children in "X_VYR_NA_SKL"
    if (updating('CIS_SKL') and :old.CIS_SKL != :new.CIS_SKL) then
       update X_VYR_NA_SKL
        set   CIS_SKL = :new.CIS_SKL
       where  CIS_SKL = :old.CIS_SKL;
    end if;
    IntegrityPackage.PreviousNestLevel;

--  gestion des erreurs
exception
    when integrity_error then
       begin
       IntegrityPackage.InitNestLevel;
       raise_application_error(errno, errmsg);
       end;
end;
/

--  Before delete trigger "tdb_x_sklad" for table "X_SKLAD"
create trigger tdb_x_sklad before delete
on X_SKLAD for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    
    --  Declaration of DeleteParentRestrict constraint for "X_PRAC_MISTO"
    cursor cfk1_x_sklad(var_cis_skl number) is
       select 1
       from   X_PRAC_MISTO
       where  CIS_SKL = var_cis_skl
        and   var_cis_skl is not null;
    
    --  Declaration of DeleteParentRestrict constraint for "X_VYR_NA_SKL"
    cursor cfk2_x_sklad(var_cis_skl number) is
       select 1
       from   X_VYR_NA_SKL
       where  CIS_SKL = var_cis_skl
        and   var_cis_skl is not null;

begin
    
    --  Cannot delete parent "X_SKLAD" if children still exist in "X_PRAC_MISTO"
    open  cfk1_x_sklad(:old.CIS_SKL);
    fetch cfk1_x_sklad into dummy;
    found := cfk1_x_sklad%FOUND;
    close cfk1_x_sklad;
    if found then
       errno  := -20006;
       errmsg := 'Children still exist in "X_PRAC_MISTO". Cannot delete parent "X_SKLAD".';
       raise integrity_error;
    end if;
    
    --  Cannot delete parent "X_SKLAD" if children still exist in "X_VYR_NA_SKL"
    open  cfk2_x_sklad(:old.CIS_SKL);
    fetch cfk2_x_sklad into dummy;
    found := cfk2_x_sklad%FOUND;
    close cfk2_x_sklad;
    if found then
       errno  := -20006;
       errmsg := 'Children still exist in "X_VYR_NA_SKL". Cannot delete parent "X_SKLAD".';
       raise integrity_error;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

--  After update trigger "tua_x_typ_vyrobku" for table "X_TYP_VYROBKU"
create trigger tua_x_typ_vyrobku after update
of OZN_TYPU
on X_TYP_VYROBKU for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
begin
    IntegrityPackage.NextNestLevel;
    
    --  Modify parent code of "X_TYP_VYROBKU" for all children in "X_DILNA_TV"
    if (updating('OZN_TYPU') and :old.OZN_TYPU != :new.OZN_TYPU) then
       update X_DILNA_TV
        set   OZN_TYPU = :new.OZN_TYPU
       where  OZN_TYPU = :old.OZN_TYPU;
    end if;
    
    --  Modify parent code of "X_TYP_VYROBKU" for all children in "X_VYR_NA_SKL"
    if (updating('OZN_TYPU') and :old.OZN_TYPU != :new.OZN_TYPU) then
       update X_VYR_NA_SKL
        set   OZN_TYPU = :new.OZN_TYPU
       where  OZN_TYPU = :old.OZN_TYPU;
    end if;
    IntegrityPackage.PreviousNestLevel;

--  gestion des erreurs
exception
    when integrity_error then
       begin
       IntegrityPackage.InitNestLevel;
       raise_application_error(errno, errmsg);
       end;
end;
/

--  Before delete trigger "tdb_x_typ_vyrobku" for table "X_TYP_VYROBKU"
create trigger tdb_x_typ_vyrobku before delete
on X_TYP_VYROBKU for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    
    --  Declaration of DeleteParentRestrict constraint for "X_VYR_NA_SKL"
    cursor cfk1_x_typ_vyrobku(var_ozn_typu varchar) is
       select 1
       from   X_VYR_NA_SKL
       where  OZN_TYPU = var_ozn_typu
        and   var_ozn_typu is not null;

begin
    
    --  Cannot delete parent "X_TYP_VYROBKU" if children still exist in "X_VYR_NA_SKL"
    open  cfk1_x_typ_vyrobku(:old.OZN_TYPU);
    fetch cfk1_x_typ_vyrobku into dummy;
    found := cfk1_x_typ_vyrobku%FOUND;
    close cfk1_x_typ_vyrobku;
    if found then
       errno  := -20006;
       errmsg := 'Children still exist in "X_VYR_NA_SKL". Cannot delete parent "X_TYP_VYROBKU".';
       raise integrity_error;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

--  After delete trigger "tda_x_typ_vyrobku" for table "X_TYP_VYROBKU"
create trigger tda_x_typ_vyrobku after delete
on X_TYP_VYROBKU for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;

begin
    IntegrityPackage.NextNestLevel;
    
    --  Delete all children in "X_DILNA_TV"
    delete X_DILNA_TV
    where  OZN_TYPU = :old.OZN_TYPU;
    IntegrityPackage.PreviousNestLevel;

--  gestion des erreurs
exception
    when integrity_error then
       begin
       IntegrityPackage.InitNestLevel;
       raise_application_error(errno, errmsg);
       end;
end;
/

--  Before insert trigger "tib_x_vyr_na_skl" for table "X_VYR_NA_SKL"
create trigger tib_x_vyr_na_skl before insert
on X_VYR_NA_SKL for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_TYP_VYROBKU"
    cursor cpk1_x_vyr_na_skl(var_ozn_typu varchar) is
       select 1
       from   X_TYP_VYROBKU
       where  OZN_TYPU = var_ozn_typu
        and   var_ozn_typu is not null;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_SKLAD"
    cursor cpk2_x_vyr_na_skl(var_cis_skl number) is
       select 1
       from   X_SKLAD
       where  CIS_SKL = var_cis_skl
        and   var_cis_skl is not null;

begin
    
    --  Parent "X_TYP_VYROBKU" must exist when inserting a child in "X_VYR_NA_SKL"
    if :new.OZN_TYPU is not null then
       open  cpk1_x_vyr_na_skl(:new.OZN_TYPU);
       fetch cpk1_x_vyr_na_skl into dummy;
       found := cpk1_x_vyr_na_skl%FOUND;
       close cpk1_x_vyr_na_skl;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_TYP_VYROBKU". Cannot create child in "X_VYR_NA_SKL".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_SKLAD" must exist when inserting a child in "X_VYR_NA_SKL"
    if :new.CIS_SKL is not null then
       open  cpk2_x_vyr_na_skl(:new.CIS_SKL);
       fetch cpk2_x_vyr_na_skl into dummy;
       found := cpk2_x_vyr_na_skl%FOUND;
       close cpk2_x_vyr_na_skl;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_SKLAD". Cannot create child in "X_VYR_NA_SKL".';
          raise integrity_error;
       end if;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

--  Before update trigger "tub_x_vyr_na_skl" for table "X_VYR_NA_SKL"
create trigger tub_x_vyr_na_skl before update
of OZN_TYPU,
   CIS_SKL
on X_VYR_NA_SKL for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    seq NUMBER;
    
    --  Declaration of UpdateChildParentExist constraint for the parent "X_TYP_VYROBKU"
    cursor cpk1_x_vyr_na_skl(var_ozn_typu varchar) is
       select 1
       from   X_TYP_VYROBKU
       where  OZN_TYPU = var_ozn_typu
        and   var_ozn_typu is not null;
    
    --  Declaration of UpdateChildParentExist constraint for the parent "X_SKLAD"
    cursor cpk2_x_vyr_na_skl(var_cis_skl number) is
       select 1
       from   X_SKLAD
       where  CIS_SKL = var_cis_skl
        and   var_cis_skl is not null;

begin
    seq := IntegrityPackage.GetNestLevel;
    
    --  Parent "X_TYP_VYROBKU" must exist when updating a child in "X_VYR_NA_SKL"
    if (:new.OZN_TYPU is not null) and (seq = 0) then 
       open  cpk1_x_vyr_na_skl(:new.OZN_TYPU);
       fetch cpk1_x_vyr_na_skl into dummy;
       found := cpk1_x_vyr_na_skl%FOUND;
       close cpk1_x_vyr_na_skl;
       if not found then
          errno  := -20003;
          errmsg := 'Parent does not exist in "X_TYP_VYROBKU". Cannot update child in "X_VYR_NA_SKL".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_SKLAD" must exist when updating a child in "X_VYR_NA_SKL"
    if (:new.CIS_SKL is not null) and (seq = 0) then 
       open  cpk2_x_vyr_na_skl(:new.CIS_SKL);
       fetch cpk2_x_vyr_na_skl into dummy;
       found := cpk2_x_vyr_na_skl%FOUND;
       close cpk2_x_vyr_na_skl;
       if not found then
          errno  := -20003;
          errmsg := 'Parent does not exist in "X_SKLAD". Cannot update child in "X_VYR_NA_SKL".';
          raise integrity_error;
       end if;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

