--  Before insert trigger "tib_x_prac_misto" for table "X_PRAC_MISTO"
create trigger tib_x_prac_misto before insert
on X_PRAC_MISTO for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy            integer;
    found            boolean;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_SKLAD"
    cursor cpk1_x_prac_misto(var_cis_skl number) is
       select 1
       from   X_SKLAD
       where  CIS_SKL = var_cis_skl
        and   var_cis_skl is not null;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_DILNA"
    cursor cpk2_x_prac_misto(var_cis_dil number) is
       select 1
       from   X_DILNA
       where  CIS_DIL = var_cis_dil
        and   var_cis_dil is not null;
    
    --  Declaration of InsertChildParentExist constraint for the parent "X_PRACOVNIK"
    cursor cpk3_x_prac_misto(var_rod_cis number) is
       select 1
       from   X_PRACOVNIK
       where  ROD_CIS = var_rod_cis
        and   var_rod_cis is not null;

begin
    
    --  Parent "X_SKLAD" must exist when inserting a child in "X_PRAC_MISTO"
    if :new.CIS_SKL is not null then
       open  cpk1_x_prac_misto(:new.CIS_SKL);
       fetch cpk1_x_prac_misto into dummy;
       found := cpk1_x_prac_misto%FOUND;
       close cpk1_x_prac_misto;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_SKLAD". Cannot create child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_DILNA" must exist when inserting a child in "X_PRAC_MISTO"
    if :new.CIS_DIL is not null then
       open  cpk2_x_prac_misto(:new.CIS_DIL);
       fetch cpk2_x_prac_misto into dummy;
       found := cpk2_x_prac_misto%FOUND;
       close cpk2_x_prac_misto;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_DILNA". Cannot create child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;
    
    --  Parent "X_PRACOVNIK" must exist when inserting a child in "X_PRAC_MISTO"
    if :new.ROD_CIS is not null then
       open  cpk3_x_prac_misto(:new.ROD_CIS);
       fetch cpk3_x_prac_misto into dummy;
       found := cpk3_x_prac_misto%FOUND;
       close cpk3_x_prac_misto;
       if not found then
          errno  := -20002;
          errmsg := 'Parent does not exist in "X_PRACOVNIK". Cannot create child in "X_PRAC_MISTO".';
          raise integrity_error;
       end if;
    end if;

--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/

-- --------------------------------------------------------------------------------- ZACATEK MOJE

-- After insert trigger "muj_trg" for table "X_PRAC_MISTO"
create or replace trigger muj_trg after insert
on X_PRAC_MISTO for each row
declare
    integrity_error  exception;
    errno            integer;
    errmsg           char(200);
    dummy1           integer;
    dummy2           integer;
    found            boolean;

    -- Deklarace after insert constraint for X_PRAC_MISTO
    cursor muj_kursor (cd number, cs number) is
	select CIS_DIL, CIS_SKL
		from x_prac_misto
		where (CIS_SKL = cs) and (CIS_DIL = cd)
--			and ((cd is null and cs is null) or
--			(cd is not null and cs is not null));
begin
    -- Vybrane radky musim zrusit
    open muj_kursor;
    fetch muj_kursor into (:dummy1, :dummy2);
    found := muj_kursor%FOUND;
    close muj_kursor;
	if not found then
	  errno  := -20000;
	  errmsg := 'Musi byt vyplnen jen jeden z atributu CIS_DIL a CIS_SKL. Radek nebyl vlozen.';
	  raise integrity_error;
	end if;
    
--  Errors handling
exception
    when integrity_error then
       raise_application_error(errno, errmsg);
end;
/
-- ----------------------------------------------------------------------------------- KONEC MOJE
